@@ -25,7 +25,7 @@ class Pipeline:
         self.model = model
         self.device = device
 
-    def ner_results(self, text, sents_tokens_list, sentences, assertion_relation=False):
+    def ner_result(self, text, sents_tokens_list, sentences, assertion_relation=False):
         """It returns the ner results of a text.
         parameters:
         ----------------
@@ -36,9 +36,11 @@ class Pipeline:
         return:
         ----------------
         ner_results: list of dict"""
-        from aimped.nlp.ner_results import NerModelResults
-        ner_results = NerModelResults(text=text, tokenizer=self.tokenizer,
-                                      model=self.model, device=self.device,
+        from aimped.nlp.ner import NerModelResults
+        ner_results = NerModelResults(text=text,
+                                      tokenizer=self.tokenizer,
+                                      model=self.model,
+                                      device=self.device,
                                       sents_tokens_list=sents_tokens_list,
                                       sentences=sentences,
                                       assertion_relation=assertion_relation
@@ -46,7 +48,7 @@ class Pipeline:
 
         return ner_results
 
-    def deid(self, text, merged_results, fake_csv_path, faked=False, masked=False):
+    def deid_result(self, text, merged_results, fake_csv_path, faked=False, masked=False):
         """It returns the deid results of a text.
         parameters:
         ----------------
@@ -59,7 +61,7 @@ class Pipeline:
         ----------------
         results: list of dict
         """
-        from aimped.nlp.deid_pipeline import maskText, fakedChunk, fakedText, deidentification
+        from aimped.nlp.deid import maskText, fakedChunk, fakedText, deidentification
         results = deidentification(text=text,
                                    merged_results=merged_results,
                                    fake_csv_path=fake_csv_path,
@@ -67,7 +69,7 @@ class Pipeline:
                                    masked=masked)
         return results
 
-    def assertion(self, ner_results, sentences, classifier, assertion_white_label_list):
+    def assertion_result(self, ner_results, sentences, classifier, assertion_white_label_list):
         """It returns the assertion results of a text.
         parameters:
         ----------------
@@ -79,7 +81,7 @@ class Pipeline:
         ----------------
         results: list of dict
         """
-        from aimped.nlp.assertion_pipeline import assertion_annotate_sentence, AssertionModelResults
+        from aimped.nlp.assertion import assertion_annotate_sentence, AssertionModelResults
         results = AssertionModelResults(ner_results=ner_results,
                                         sentences=sentences,
                                         classifier=classifier,
@@ -136,15 +138,16 @@ class Pipeline:
         from aimped.nlp.regex_parser import RegexNerParser, RegexModelNerMerger, RegexModelNerChunkResults
         import glob
         regex_json_files_path_list = glob.glob(f"{regex_json_files_path}/*.json")
+
         merged_results = RegexModelNerChunkResults(regex_json_files_path_list=regex_json_files_path_list,
                                                    model_results=model_results,
                                                    text=text,
                                                    white_label_list=white_label_list)
         return merged_results
 
-    def relation_results(self, sentences, ner_chunk_results, relation_classifier,
-                         ner_white_label_list, relation_white_label_list, one_to_many=True,
-                         one_label=None, return_svg=False):
+    def relation_result(self, sentences, ner_chunk_results, relation_classifier,
+                        ner_white_label_list, relation_white_label_list, one_to_many=True,
+                        one_label=None, return_svg=False):
         """It returns the relation results of a text.
         parameters:
         ----------------
@@ -160,10 +163,15 @@ class Pipeline:
         ----------------
         results: list of dict
         """
-        from aimped.nlp.relation_pipeline import RelationResults, relation_annotate_sentence
-        results = RelationResults(sentences, ner_chunk_results, relation_classifier,
-                                  ner_white_label_list, relation_white_label_list, one_to_many=one_to_many,
-                                  one_label=one_label, return_svg=return_svg)
+        from aimped.nlp.relation import RelationResults, relation_annotate_sentence
+        results = RelationResults(sentences=sentences,
+                                  ner_chunk_results=ner_chunk_results,
+                                  relation_classifier=relation_classifier,
+                                  ner_white_label_list=ner_white_label_list,
+                                  relation_white_label_list=relation_white_label_list,
+                                  one_to_many=one_to_many,
+                                  one_label=one_label,
+                                  return_svg=return_svg)
         return results
 
     def __str__(self) -> str:
@@ -200,9 +208,9 @@ if __name__ == "__main__":
 
     # test pipeline
     pipe = Pipeline(model=model, tokenizer=tokenizer, device='cpu')
-    tokens, preds, probs, begins, ends = pipe.ner_results(text=text,
-                                                          sents_tokens_list=sents_tokens_list,
-                                                          sentences=sentences)
+    tokens, preds, probs, begins, ends = pipe.ner_result(text=text,
+                                                         sents_tokens_list=sents_tokens_list,
+                                                         sentences=sentences)
     # print("tokens: ", tokens)
     # print("preds: ", preds)
     # print("probs:", probs)
@@ -218,7 +226,7 @@ if __name__ == "__main__":
 
     # test deid
     fake_csv_path = r"C:\Users\rcali\Desktop\kubeflow\deid-ner-gitlab\nlp-health-deidentification-sub-base-en\fake.csv"
-    deid_results = pipe.deid(text, merged_results, fake_csv_path, faked=True, masked=True)
+    deid_results = pipe.deid_result(text, merged_results, fake_csv_path, faked=True, masked=True)
     import pprint
 
     pprint.pprint(deid_results, indent=1)
